scoretools.GrandStaff
=====================

.. abjad-lineage:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff

.. autoclass:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.descendants
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.leaves
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.lineage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.music
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.override
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.parent
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.parentage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.prolation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.set
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.spanners
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.start_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.storage_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.timespan
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.context_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.append
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.index
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__add__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__iadd__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__imul__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__le__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__radd__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff.__setitem__
   :noindex:
